#[repr(i32)]pub enum ParticipantState {
Online = 0,
Offline = 1,
}Variants
Implementations
Sourceimpl ParticipantState
impl ParticipantState
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ParticipantState.
Sourcepub fn from_i32(value: i32) -> Option<ParticipantState>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ParticipantState>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ParticipantState, or None if value is not a valid variant.
Sourceimpl ParticipantState
impl ParticipantState
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ParticipantState>
pub fn from_str_name(value: &str) -> Option<ParticipantState>
Creates an enum from field names used in the ProtoBuf definition.