#[repr(i32)]pub enum ProtoSessionMessageType {
Show 19 variants
Unspecified = 0,
Msg = 1,
MsgAck = 2,
RtxRequest = 3,
RtxReply = 4,
DiscoveryRequest = 5,
DiscoveryReply = 6,
JoinRequest = 7,
JoinReply = 8,
LeaveRequest = 9,
LeaveReply = 10,
GroupAdd = 11,
GroupRemove = 12,
GroupWelcome = 13,
GroupClose = 14,
GroupProposal = 15,
GroupAck = 16,
GroupNack = 17,
Ping = 18,
}Variants
Unspecified = 0
Msg = 1
MsgAck = 2
RtxRequest = 3
RtxReply = 4
DiscoveryRequest = 5
DiscoveryReply = 6
JoinRequest = 7
JoinReply = 8
LeaveRequest = 9
LeaveReply = 10
GroupAdd = 11
GroupRemove = 12
GroupWelcome = 13
GroupClose = 14
GroupProposal = 15
GroupAck = 16
GroupNack = 17
Ping = 18
Implementations
Sourceimpl SessionMessageType
impl SessionMessageType
pub fn is_command_message(&self) -> bool
pub fn is_post_session_control(&self) -> bool
Sourceimpl SessionMessageType
impl SessionMessageType
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SessionMessageType.
Sourcepub fn from_i32(value: i32) -> Option<SessionMessageType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SessionMessageType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SessionMessageType, or None if value is not a valid variant.
Sourceimpl SessionMessageType
impl SessionMessageType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SessionMessageType>
pub fn from_str_name(value: &str) -> Option<SessionMessageType>
Creates an enum from field names used in the ProtoBuf definition.