pub struct GroupProposalPayload {
pub source: Option<Name>,
pub mls_proposal: Vec<u8>,
}Expand description
Group Proposal sent on mls key rotation
Fields
source: Option<Name>Original name of the endpoint that crated the proposal name this may by different from the packet source since it is forwarded by the moderator on the channel to all the group participants
mls_proposal: Vec<u8>MLS proposal message