pub struct GroupUpdatePayload {
pub op: i32,
pub participant: Option<Participant>,
pub participants: Vec<Participant>,
pub mls: Option<MlsPayload>,
}Expand description
Group Update Payload sent when participant is added, removed or is rejoining the group
Fields
op: i32operation to perform (add/rm/rejoin)
participant: Option<Participant>participant that triggered the add/rm/rejoin
participants: Vec<Participant>updated list of participants and their status
mls: Option<MlsPayload>used only when MLS is enabled
Implementations
Sourceimpl GroupUpdatePayload
impl GroupUpdatePayload
Sourcepub fn op(&self) -> GroupUpdateOp
pub fn op(&self) -> GroupUpdateOp
Returns the enum value of op, or the default if the field is set to an invalid enum value.
Sourcepub fn set_op(&mut self, value: GroupUpdateOp)
pub fn set_op(&mut self, value: GroupUpdateOp)
Sets op to the provided enum value.