pub struct MlsPayload {
pub commit_id: u32,
pub mls_content: Vec<u8>,
}Expand description
MLS payload to add to the group messages when mls is active
Fields
commit_id: u32the commit id for add/rm participants the last commit id sent by the moderator in case of welcome message
mls_content: Vec<u8>commit or welcome mls message