pub struct MessageProcessor { /* private fields */ }Implementations
Sourceimpl MessageProcessor
impl MessageProcessor
pub fn new_with_service_id(service_id: String) -> Self
Sourcepub fn new_with_server_config(
service_id: String,
deployment_name: String,
server_config: &ServerConfig,
relay_peer_publishes: bool,
) -> Self
pub fn new_with_server_config( service_id: String, deployment_name: String, server_config: &ServerConfig, relay_peer_publishes: bool, ) -> Self
Create a processor with the server strict header MAC policy from server_config.
pub fn new() -> Self
Sourcepub async fn run_server(
&self,
config: &ServerConfig,
) -> Result<CancellationToken, DataPathError>
pub async fn run_server( &self, config: &ServerConfig, ) -> Result<CancellationToken, DataPathError>
Run a data plane server using this message processor’s drain watch.
Dispatch on the configured transport happens inside slim-config via the
ServerHandler trait below. Returns a cancellation token that can be
used to stop the server task.
Sourcepub fn signal_drain(&self)
pub fn signal_drain(&self)
Signal all spawned tasks (process_stream, etc.) to begin shutting down.
Unlike [shutdown], this is synchronous: it drops the drain signal (which
notifies all drain watches) and the drain watch, but does NOT wait for the
tasks to finish. Safe to call from a synchronous Drop implementation.
pub async fn shutdown(&self) -> Result<(), DataPathError>
pub fn forwarder(&self) -> &Forwarder<Connection>
pub async fn connect( &self, client_config: ClientConfig, local: Option<SocketAddr>, remote: Option<SocketAddr>, ) -> Result<(JoinHandle<()>, u64), DataPathError>
pub fn disconnect(&self, conn: u64) -> Result<ClientConfig, DataPathError>
pub fn register_local_connection( &self, from_control_plane: bool, ) -> Result<(u64, Sender<Result<Message, Status>>, Receiver<Result<Message, Status>>), DataPathError>
pub async fn send_msg( &self, msg: Message, out_conn: u64, ) -> Result<(), DataPathError>
pub async fn process_message( &self, msg: Message, in_connection: u64, category: ConnType, ) -> Result<(), DataPathError>
pub fn subscription_table(&self) -> &SubscriptionTableImpl
pub fn connection_table(&self) -> &ConnectionTable<Connection>
Sourcepub fn service_id(&self) -> &str
pub fn service_id(&self) -> &str
The node identity used for cross-node communication.
Sourcepub fn set_peer_sync(&self, peer_sync: PeerSync)
pub fn set_peer_sync(&self, peer_sync: PeerSync)
Set the peer sync component.