pub enum MessageType {
Subscribe(Subscribe),
Unsubscribe(Unsubscribe),
Publish(Publish),
Link(Link),
SubscriptionAck(SubscriptionAck),
}Variants
Subscribe(Subscribe)
Unsubscribe(Unsubscribe)
Publish(Publish)
Link(Link)
SubscriptionAck(SubscriptionAck)
Implementations
Sourceimpl MessageType
impl MessageType
Sourcepub fn merge(
field: &mut Option<MessageType>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<MessageType>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.