#[repr(i32)]pub enum ProtoSessionMessageType {
Show 19 variants
Unspecified = 0,
Msg = 1,
MsgAck = 2,
RtxRequest = 3,
RtxReply = 4,
DiscoveryRequest = 5,
DiscoveryReply = 6,
JoinRequest = 7,
JoinReply = 8,
LeaveRequest = 9,
LeaveReply = 10,
GroupAdd = 11,
GroupRemove = 12,
GroupWelcome = 13,
GroupClose = 14,
GroupProposal = 15,
GroupAck = 16,
GroupNack = 17,
Ping = 18,
}Variants
Unspecified = 0
Msg = 1
MsgAck = 2
RtxRequest = 3
RtxReply = 4
DiscoveryRequest = 5
DiscoveryReply = 6
JoinRequest = 7
JoinReply = 8
LeaveRequest = 9
LeaveReply = 10
GroupAdd = 11
GroupRemove = 12
GroupWelcome = 13
GroupClose = 14
GroupProposal = 15
GroupAck = 16
GroupNack = 17
Ping = 18
Implementations
Sourceimpl SessionMessageType
impl SessionMessageType
Sourcepub fn from_i32(value: i32) -> Option<SessionMessageType>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SessionMessageType>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SessionMessageType, or None if value is not a valid variant.
Sourceimpl SessionMessageType
impl SessionMessageType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.
Sourceimpl SessionMessageType
SessionMessageType
Helper methods for session message types
impl SessionMessageType
SessionMessageType Helper methods for session message types
Sourcepub fn is_command_message(&self) -> bool
pub fn is_command_message(&self) -> bool
Check if a message type is a command message (not application data)